#include <iostream>
#include "urlstream.h"
#include "console.h"
#include "simpio.h"
#include <string>
#include "strlib.h"

using namespace std;

void fetchLyrics(istream& inputStream, ostream& outputStream);
void fixLine(string& line);

int main() {
    string artist = getLine("Enter artist: ");
    string songTitle = getLine("Enter song title: ");
    iurlstream urlStream("https://api.lyrics.ovh/v1/" + artist + "/" + songTitle);
    fetchLyrics(urlStream, cout);
    return 0;
}

/* This function reads lyrics from an input stream, cleans
 * them up of newline and other excess characters, and outputs
 * them to the specified output stream.
 */
void fetchLyrics(istream& inputStream, ostream& outputStream) {
    string line;
    while (getline(inputStream, line)) {
        fixLine(line);
        outputStream << line;
    }
}

/* This function replaces all instances of "\n" in a
 * string with an actual 'newline' character ('\n').
 * It also removes leading or trailing
 * artifacts from possibly fetching from the web.
 */
void fixLine(string& line) {
    // Remove leading artifacts
    if (startsWith(line, "{\"lyrics\":\"")) {
        line.erase(0, 11);
    }

    // Remove trailing artifacts
    if (endsWith(line, "\"}")) {
        line.erase(line.length() - 2, 2);
    }

    // Replace each "\n" with a '\n'
    int newLineIndex = line.find("\\n");
    while (newLineIndex != string::npos) {
        line.replace(newLineIndex, 2, "\n");
        newLineIndex = line.find("\\n");
    }
}
